@@ -44,10 +44,17 @@
 #'
 #' @examples
 #' \donttest{
-#' ### Usage with stanreg objects
-#' fit <- stan_glm(y~x, binomial())
-#' cvs <- cv_varsel(fit)
-#' varsel_plot(cvs)
+#' if (requireNamespace('rstanarm', quietly=TRUE)) {
+#'   ### Usage with stanreg objects
+#'   n <- 30
+#'   d <- 5
+#'   x <- matrix(rnorm(n*d), nrow=n)
+#'   y <- x[,1] + 0.5*rnorm(n)
+#'   data <- data.frame(x,y)
+#'   fit <- rstanarm::stan_glm(y~., gaussian(), data=data, chains=2, iter=500)
+#'   cvs <- cv_varsel(fit)
+#'   varsel_plot(cvs)
+#' }
 #' }
 #'
 
@@ -436,8 +443,10 @@ loo_varsel <- function(refmodel, method, nv_max, ns, nc, nspred, ncpred, relax,
   # belong to the semi random subsample of validation points)
   
   # set random seed but ensure the old RNG state is restored on exit
-  rng_state_old <- .Random.seed
-  on.exit(assign(".Random.seed", rng_state_old, envir = .GlobalEnv))
+  if (exists('.Random.seed')) {
+    rng_state_old <- .Random.seed
+    on.exit(assign(".Random.seed", rng_state_old, envir = .GlobalEnv))
+  }
   set.seed(seed)
   
   resample <- function(x, ...) x[sample.int(length(x), ...)]
