@@ -42,15 +42,23 @@
 #'
 #' @examples
 #' \donttest{
-#' ### Usage with stanreg objects
-#' fit <- stan_glm(y~x, binomial())
-#' vs <- varsel(fit)
-#' 
-#' # project onto the best model with 4 variables
-#' proj4 <- project(vs, nv = 4)
-#' 
-#' # project onto an arbitrary variable combination (variable indices 3,4 and 8)
-#' proj <- project(fit, vind=c(3,4,8))
+#' if (requireNamespace('rstanarm', quietly=TRUE)) {
+#'   ### Usage with stanreg objects
+#'   n <- 30
+#'   d <- 5
+#'   x <- matrix(rnorm(n*d), nrow=n)
+#'   y <- x[,1] + 0.5*rnorm(n)
+#'   data <- data.frame(x,y)
+#'   
+#'   fit <- rstanarm::stan_glm(y~., gaussian(), data=data, chains=2, iter=500)
+#'   vs <- varsel(fit)
+#'   
+#'   # project onto the best model with 4 variables
+#'   proj4 <- project(vs, nv = 4)
+#'   
+#'   # project onto an arbitrary variable combination (variable indices 1, 3 and 5)
+#'   proj <- project(fit, vind=c(1,3,5))
+#' }
 #' }
 #'
 
@@ -58,12 +66,12 @@
 project <- function(object, nv = NULL, vind = NULL, relax = NULL, ns = NULL, nc = NULL, 
                     intercept = NULL, seed = NULL, regul=1e-4, ...) {
 
-	if ( !('vsel' %in% class(object) || 'cvsel' %in% class(object)) && is.null(vind) )
-		stop(paste('The given object is not a variable selection -object.',
-							 'Run the variable selection first, or provide the variable indices (vind).'))
+  if (!inherits(object, c('vsel', 'cvsel')) && is.null(vind))
+    stop(paste('The object is not a variable selection object.',
+               'Run variable selection first, or provide the variable indices (vind).'))
+
+  refmodel <- get_refmodel(object)
 
-	refmodel <- get_refmodel(object)
-  
   if (is.null(relax)) 
   	# use non-relaxed solution for datafits by default
     relax <- ifelse('datafit' %in% class(get_refmodel(object)), FALSE, TRUE)
@@ -72,6 +80,8 @@ project <- function(object, nv = NULL, vind = NULL, relax = NULL, ns = NULL, nc
     relax <- TRUE
 
   if (!is.null(vind)) {
+    if (max(vind) > ncol(refmodel$x))
+      stop('vind contains an index larger than ', ncol(refmodel$x), '.')
     nv <- length(vind) # if vind is given, nv is ignored (project only onto the given submodel)
   } else {
     vind <- object$vind # by default take the variable ordering from the selection
@@ -85,6 +95,14 @@ project <- function(object, nv = NULL, vind = NULL, relax = NULL, ns = NULL, nc
       nv <- object$ssize # by default, project onto the suggested model size
     else
       stop('No suggested model size found, please specify nv or vind')
+  } else {
+    if (!is.numeric(nv) || any(nv < 0))
+      stop('nv must contain non-negative values.')
+    if (max(nv) > length(vind)) {
+      stop(paste('Cannot perform the projection with', max(nv), 'variables,',
+                 'because variable selection was run only up to', length(vind),
+                 'variables.'))
+    }
   }
 
 	if (is.null(intercept))
@@ -92,11 +110,6 @@ project <- function(object, nv = NULL, vind = NULL, relax = NULL, ns = NULL, nc
 
 	family_kl <- refmodel$fam
 
-	if (max(nv) > length(vind))
-	  stop(paste('Cannot perform the projection with', max(nv), 'variables,',
-	             'because the variable selection has been run only up to',
-	             length(object$vind), 'variables.'))
-
 	# training data
 	d_train <- .get_traindata(refmodel)
 
